==> CNAnorm_1.2.0.tar.gz: CNAnorm/R/AllGenerics.R <==
setGeneric("gcC", function(object){standardGeneric("gcC")})
setGeneric("chrs", function(object){standardGeneric("chrs")})
setGeneric("pos", function(object){standardGeneric("pos")})
setGeneric("get.adjust", function(object){standardGeneric("get.adjust")})
setGeneric("get.n", function(object){standardGeneric("get.n")})

setGeneric("ratio", function(object){standardGeneric("ratio")})
setGeneric("ratio.n", function(object){standardGeneric("ratio.n")})
setGeneric("segID", function(object){standardGeneric("segID")})
setGeneric("ratio.s", function(object){standardGeneric("ratio.s")})
setGeneric("ratio.s.n", function(object){standardGeneric("ratio.s.n")})
setGeneric("segMean", function(object){standardGeneric("segMean")})
setGeneric("segMean.n", function(object){standardGeneric("segMean.n")})
setGeneric("sugg.peaks",function(object){standardGeneric("sugg.peaks")})
setGeneric("sugg.ploidy",function(object){standardGeneric("sugg.ploidy")})
setGeneric("valid.peaks",function(object){standardGeneric("valid.peaks")})
setGeneric("valid.ploidy",function(object){standardGeneric("valid.ploidy")})
setGeneric("chrs<-", function(object, value){standardGeneric("chrs<-")})
setGeneric("pos<-", function(object, value){standardGeneric("pos<-")})
setGeneric("gcNorm", function(object, ...){standardGeneric("gcNorm")})
setGeneric("addSmooth", function(object, ...){standardGeneric("addSmooth")})
setGeneric("addDNACopy", function(object){standardGeneric("addDNACopy")})
setGeneric("validation", function(object, ...){standardGeneric("validation")})
setGeneric("discreteNorm", function(object, ...){standardGeneric("discreteNorm")})
setGeneric("peakPloidy", function(object, ...){standardGeneric("peakPloidy")})
setGeneric("plotGenome", function(object, ...){standardGeneric("plotGenome")})
setGeneric("plotPeaks", function(object, ...){standardGeneric("plotPeaks")})
setGeneric("exportTable", function(object, ...){standardGeneric("exportTable")})
setGeneric("summary")# , function(object, ...){standardGeneric("summary")})
setGeneric("as.data.frame")# , function(object, ...){standardGeneric("summary")})
setGeneric("length")# , function(object, ...){standardGeneric("summary")})
# setGeneric("suggest.k", function(object, ...){standardGeneric("suggest.k")})

==> CNAnorm_1.22.1.tar.gz: CNAnorm/R/AllGenerics.R <==
setGeneric("gcC", function(object){standardGeneric("gcC")})
setGeneric("chrs", function(object){standardGeneric("chrs")})
setGeneric("pos", function(object, ...){standardGeneric("pos")})
setGeneric("arms", function(object, ...){standardGeneric("arms")})
setGeneric("get.adjust", function(object){standardGeneric("get.adjust")})
setGeneric("get.n", function(object){standardGeneric("get.n")})

setGeneric("ratio", function(object){standardGeneric("ratio")})
setGeneric("ratio.n", function(object){standardGeneric("ratio.n")})
setGeneric("segID", function(object){standardGeneric("segID")})
setGeneric("ratio.s", function(object){standardGeneric("ratio.s")})
setGeneric("ratio.s.n", function(object){standardGeneric("ratio.s.n")})
setGeneric("segMean", function(object){standardGeneric("segMean")})
setGeneric("segMean.n", function(object){standardGeneric("segMean.n")})
setGeneric("sugg.peaks",function(object){standardGeneric("sugg.peaks")})
setGeneric("sugg.ploidy",function(object){standardGeneric("sugg.ploidy")})
setGeneric("valid.peaks",function(object){standardGeneric("valid.peaks")})
setGeneric("valid.ploidy",function(object){standardGeneric("valid.ploidy")})
setGeneric("chrs<-", function(object, value){standardGeneric("chrs<-")})
setGeneric("pos<-", function(object, value){standardGeneric("pos<-")})
setGeneric("gcNorm", function(object, ...){standardGeneric("gcNorm")})
setGeneric("addSmooth", function(object, ...){standardGeneric("addSmooth")})
setGeneric("addDNACopy", function(object, ...){standardGeneric("addDNACopy")})
setGeneric("validation", function(object, ...){standardGeneric("validation")})
setGeneric("discreteNorm", function(object, ...){standardGeneric("discreteNorm")})
setGeneric("peakPloidy", function(object, ...){standardGeneric("peakPloidy")})
setGeneric("plotGenome", function(object, ...){standardGeneric("plotGenome")})
setGeneric("plotPeaks", function(object, ...){standardGeneric("plotPeaks")})
setGeneric("exportTable", function(object, ...){standardGeneric("exportTable")})
setGeneric("summary")# , function(object, ...){standardGeneric("summary")})
setGeneric("as.data.frame")# , function(object, ...){standardGeneric("summary")})
setGeneric("length")# , function(object, ...){standardGeneric("summary")})
# setGeneric("suggest.k", function(object, ...){standardGeneric("suggest.k")})
